@@ -7,7 +7,11 @@ use Mo qw(build is);
 use Mo::utils 0.08 qw(check_isa check_length check_required);
 use Mo::utils::URI 0.02 qw(check_location check_uri);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
+
+has icon => (
+	is => 'ro',
+);
 
 has icon_url => (
 	is => 'ro',
@@ -28,6 +32,9 @@ has uri => (
 sub BUILD {
 	my $self = shift;
 
+	# Check icon.
+	check_isa($self, 'icon', 'Data::Icon');
+
 	# Check icon_url.
 	check_location($self, 'icon_url');
 	# TODO Check image
@@ -59,9 +66,10 @@ Data::InfoBox::Item - Data object for info box item.
 
 =head1 SYNOPSIS
 
- use Data::InfoBox;
+ use Data::InfoBox::Item;
 
  my $obj = Data::InfoBox::Item->new(%params);
+ my $icon = $obj->icon;
  my $icon_url = $obj->icon_url;
  my $icon_char = $obj->icon_char;
  my $text = $obj->text;
@@ -77,14 +85,26 @@ Constructor.
 
 =over 8
 
+=item * C<icon>
+
+Icon for item.
+
+It's L<Data::Icon> object.
+
+It's optional.
+
 =item * C<icon_url>
 
+I<Parameter will be deprecated. Use 'icon' parameter.>
+
 Icon URL.
 
 It's optional.
 
 =item * C<icon_char>
 
+I<Parameter will be deprecated. Use 'icon' parameter.>
+
 Icon character. Could be UTF-8 character. Only one character.
 
 It's optional.
@@ -105,6 +125,14 @@ It's optional.
 
 Returns instance of object.
 
+=head2 C<icon>
+
+ my $icon = $obj->icon;
+
+Get icon.
+
+Returns L<Data::Icon> instance.
+
 =head2 C<icon_url>
 
  my $icon_url = $obj->icon_url;
@@ -141,6 +169,9 @@ Returns string.
 
  new():
          From Mo::utils:
+                 Parameter 'icon' must be a 'Data::Icon' object.
+                         Value: %s
+                         Reference: %s
                  Parameter 'icon_char' has length greater than '1'.
                          Value: %s
                  Parameter 'text' is required.
@@ -161,11 +192,14 @@ Returns string.
  use strict;
  use warnings;
 
+ use Data::Icon;
  use Data::InfoBox::Item;
  use Data::Text::Simple;
 
  my $obj = Data::InfoBox::Item->new(
-         'icon_url' => 'https://example.com/foo.png',
+         'icon' => Data::Icon->new(
+                 'url' => 'https://example.com/foo.png',
+         ),
          'text' => Data::Text::Simple->new(
                  'text' => 'Funny item'
          ),
@@ -173,7 +207,7 @@ Returns string.
  );
 
  # Print out.
- print "Icon URL: ".$obj->icon_url."\n";
+ print "Icon URL: ".$obj->icon->url."\n";
  print "Text: ".$obj->text->text."\n";
  print "URI: ".$obj->uri."\n";
 
@@ -214,12 +248,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2024 Michal Josef Špaček
+© 2024-2025 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
