@@ -8,7 +8,7 @@ use Data::InfoBox::Item;
 use Data::Text::Simple;
 use Unicode::UTF8 qw(decode_utf8);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub new {
 	my $class = shift;
@@ -121,12 +121,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2024 Michal Josef Špaček
+© 2024-2025 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
